Chiplotle Compound commands — Chiplotle v0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.1 documentation »
- Chiplotle API »

# Chiplotle Compound commands

mod: | chiplotle.hpgl.compound

class `chiplotle.hpgl.compound.circle.` `Circle`(xy, radius, chord=None, filled=False, pen=None)

  Bases: `chiplotle.hpgl.compound.compound._CompoundHPGL`

  Circle with absolute position.

class `chiplotle.hpgl.compound.compound.` `_CompoundHPGL`(xy, pen=None)

  Bases: `chiplotle.hpgl.abstract.positional._Positional`

  `format`
  `pen`
  `xabsolute`
  `xyabsolute`
  `yabsolute`

class `chiplotle.hpgl.compound.container.` `Container`(xy, shapes=None, pen=None)

  Bases: `chiplotle.hpgl.compound.compound._CompoundHPGL`, `list`

  Generic container.

class `chiplotle.hpgl.compound.groovyframe.` `GroovyFrame`(xy, wh1, wh2, linesPerSide, pen=None)
  Bases: `chiplotle.hpgl.compound.compound._CompoundHPGL`

class `chiplotle.hpgl.compound.label.` `Label`(xy, text)

  Bases: `chiplotle.hpgl.compound.compound._CompoundHPGL`

  Text label.

  - xy: 2-tuple of coordinates pair for label location.

  - text: The actual text to be printed.

  - charsize: 2-tuple (w, h) pair defining the absolute character size.

  - direction: 2-tuple. The inclination / angle of the text:

      run (direction on x axis), rise (direction on y axis).

  - charspace: Factor to set spacing between characters.

      Positive separates, negatives bring together.

  - linespace: Factor to set spacing between lines.

      Positive separates, negatives bring together.

  - origin: location of label relative to pen’s current location.

      Possible values:

      > . | Left | Inside | Right
      > --- | --- | --- | ---
      > Above | 3 | 6 | 9
      > Inside | 2 | 5 | 8
      > Below | 1 | 4 | 7

      > If 10 is added to the above-mentioned location number, positions (except 5) will be offset towards the center by 1/2 the character width and 1/2 the character height.

  - slant: slant of characters (italic). Possible values: [0-1).

      0 is vertical, 0.5 is 45 degs., ...

  - vertical: Print text from left to right (False) or top down (True).

  `charsize`

class `chiplotle.hpgl.compound.mayanumber.` `MayaNumber`(xy, value, size=500)
  Bases: `chiplotle.hpgl.compound.compound._CompoundHPGL`

class `chiplotle.hpgl.compound.randomwalk.` `RandomWalk`(xy, steps, stepSize=500)

  Bases: `chiplotle.hpgl.compound.compound._CompoundHPGL`

  Random Walk.

class `chiplotle.hpgl.compound.rectangle.` `Rectangle`(xy, width, height, rotation=0)

  Bases: `chiplotle.hpgl.compound.compound._CompoundHPGL`

  Compound Rectangle. Can be rotated. Cannot be filled

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.1 documentation »
- Chiplotle API »